==> ejc-analysis-api-3.0.0-20240429.015931-170-sources.jar: com/ejianc/business/analysis/vo/RequestVO.java <==
package com.ejianc.business.analysis.vo;

import java.util.List;


/**
 * 现场管理费
 * 
 * @author generator
 * 
 */
public class RequestVO  {
    private static final long serialVersionUID = 1L;

    private Integer inAdvanceFlag;
    private String day;
    private List<Long> projectIdList;
    private Integer billState;
    private String reportingMonth;
    private String analusisName;//更新报表名称
    private String updateUserName; // 更新人

    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getAnalusisName() {
        return analusisName;
    }

    public void setAnalusisName(String analusisName) {
        this.analusisName = analusisName;
    }

    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Integer getInAdvanceFlag() {
        return inAdvanceFlag;
    }

    public void setInAdvanceFlag(Integer inAdvanceFlag) {
        this.inAdvanceFlag = inAdvanceFlag;
    }

    public String getDay() {
        return day;
    }

    public void setDay(String day) {
        this.day = day;
    }

    public List<Long> getProjectIdList() {
        return projectIdList;
    }

    public void setProjectIdList(List<Long> projectIdList) {
        this.projectIdList = projectIdList;
    }
}

==> ejc-analysis-api-3.0.0-20250813.020136-305-sources.jar: com/ejianc/business/analysis/vo/RequestVO.java <==
package com.ejianc.business.analysis.vo;

import java.util.List;


/**
 * 现场管理费
 * 
 * @author generator
 * 
 */
public class RequestVO  {
    private static final long serialVersionUID = 1L;

    private Integer inAdvanceFlag;
    private String day;
    private List<Long> projectIdList;
    private String billState;
    private String reportingMonth;
    private String analusisName;//更新报表名称
    private String updateUserName; // 更新人

    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getAnalusisName() {
        return analusisName;
    }

    public void setAnalusisName(String analusisName) {
        this.analusisName = analusisName;
    }

    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }

    public String getBillState() {
        return billState;
    }

    public void setBillState(String billState) {
        this.billState = billState;
    }

    public Integer getInAdvanceFlag() {
        return inAdvanceFlag;
    }

    public void setInAdvanceFlag(Integer inAdvanceFlag) {
        this.inAdvanceFlag = inAdvanceFlag;
    }

    public String getDay() {
        return day;
    }

    public void setDay(String day) {
        this.day = day;
    }

    public List<Long> getProjectIdList() {
        return projectIdList;
    }

    public void setProjectIdList(List<Long> projectIdList) {
        this.projectIdList = projectIdList;
    }
}
